*PALMS earnings, incorporating code from Martin Wittenberg into the PALMS do files. 
*July 2013
*Andrew Kerr
*revised October 2015
*further revised May 2016

set more off
cap log close
clear all


local palmsmergefolder="C:\Users\01430870\Desktop\Andy\DataFirst\main project\PALMS"
*local palmsmergefolder="C:\Users\user\Desktop\Andy\DataFirst\PALMS"

use "`palmsmergefolder'\palmsv3.3nowageadj.dta", replace

*dropping some variables to make the code for earnings run quicker
keep wave uqnr personnr dwelltype watersource toiletmaintype hhpension hhchildsuppgrant hhcaredependgrant hhfostercaregrant incpension incdisabgrnt incdepgrnt inctstmaint incfostcrgrnt ///
enrolled enrollment3 stratum ea dc

save "`palmsmergefolder'\palmsv3.3forfinalmerge.dta", replace

use "`palmsmergefolder'\palmsv3.3nowageadj.dta", replace
drop dwelltype watersource toiletmaintype hhpension hhchildsuppgrant hhcaredependgrant hhfostercaregrant incpension incdisabgrnt incdepgrnt inctstmaint incfostcrgrnt ///
enrolled enrollment3 stratum ea dc


*OHs 94
gen wage_earnings=wageempincome2 if imputed==0
*replace wage_earnings=wageempincome2-deduc if gros_pay==1	& deduc<salary_r		// The assumption here is that the "wageempincome2" figure is not actually net - based on the CDFs
																			// We are forcing net earnings to be positive
gen selfempinc=selfempincome2  if impute_gross==0
replace selfempinc=. if selfempincome2 ==0								// selfempincome2 has no missings at all. It contains 98083 values of zero.\
gen expenses=selfempexpall
replace expenses=. if expenses==99999|expenses==99998
replace expenses=round(expenses/12,1) if earnperiod_self==4

gen selfempincnet=selfempinc-expenses 

*** Generate earnings for OHS 95-99

replace wage_earnings = wageempincome if wave!=1		// This means that the missing earnings period info in 1998 and 1999 is assigned to the monthly	category
replace wage_earnings = int(wageempincome*22) if earnperiod_wage==1 & wave!=1
replace wage_earnings = round(wageempincome*4.333333,1) if earnperiod_wage==2 & wave!=1
replace wage_earnings = round(wageempincome/12,1) if earnperiod_wage==4 & wave!=1

replace selfempinc=selfempincome1 if selfempinc==.		// Note that Missing self-earnings period is set to monthly
replace selfempinc=selfempinc*22 if earnperiod_self==1 & wave!=1
replace selfempinc=round(selfempinc*4.333333,1) if earnperiod_self==2 & wave!=1
replace selfempinc=round(selfempinc/12,1) if earnperiod_self==4 & wave!=1

replace selfempexpall=. if selfempexpall==99999
replace expenses=selfempexpall if wave==2

replace selfempexpgoods=0 if selfempexpgoods==. & selfempinc<.
replace selfempexprenum=0 if selfempexprenum==. & selfempinc<.
replace selfempexpoth=0 if selfempexpoth==. & selfempinc<.
replace selfempexpgoods=0 if selfempexpgoods==. & selfempinccat2<.
replace selfempexprenum=0 if selfempexprenum==. & selfempinccat2<.
replace selfempexpoth=0 if selfempexpoth==. & selfempinccat2<.

replace expenses=selfempexpgoods+ selfempexprenum+ selfempexpoth if expenses==.
table wave earnperiod_self, c(m expenses)
replace expenses=round(expenses/12,1) if earnperiod_self==4

replace selfempincnet=selfempinc-expenses if wave==2|wave==4|wave==5
replace selfempincnet=selfempinc if wave==6								// figure is net in 1999
gen byte negearnings=selfempincnet<0 if selfempincnet<.
table wave earnperiod_self, c(n negearnings m negearnings)
drop negearnings

replace selfempincnet=. if selfempincnet<0




***** Now we need to assemble the different types of earnings into one variable

gen byte wageinfo=(wage_earnings>=0&wage_earnings<.)| (empsalcat1>0&empsalcat1<=14) | (empsalcat2>0&empsalcat2<=29) | empsalcat3<=11
gen byte selfinfo=(selfempincnet>0&selfempincnet<.)|( selfempinccat1>1& selfempinccat1<=14)|(selfempinccat2>1&selfempinccat2<=16)|(selfempinccat3>2&selfempinccat3<=29)|(selfempinccat4>2&selfempinccat4<=13)
		// note that I have presumed that zero self employment income is not informative, but have allowed it for wage income

gen byte earningsinfo=0
replace earningsinfo=1 if wageinfo==1
replace earningsinfo=2 if selfinfo==1
replace earningsinfo=3 if wageinfo==1&selfinfo==1

tab earningsinfo employer1, missing
tab wave earningsinfo if wave<=6
tab wave earningsinfo if wave<=6&earningsinfo>0, row

gen earnings=wage_earnings
replace earnings=selfempincnet if employer1==2
replace earnings=selfempincnet if employer1==3 & (earnings==. | (earnings==0 & selfempincnet<.))
replace earnings=selfempincnet if employer1==. & earningsinfo==2

*LFS data
replace earnings = jobsalary if earnperiod==3 & wave>=7				// LFSs
replace earnings = jobsalary*4.33 if earnperiod==2 & wave>=7
replace earnings = jobsalary/12 if earnperiod==4 & wave>=7

*QLFS data
replace monthlyjobsalary=. if monthlyjobsalary==888888 /*90 obs higher than 100000 pm, highest monthly salary 400000, but odd that 11 obs with that amount*/
/*now with data 2012 2014 included it looks weirder! 449 obs have exactly 400000 pm and most of these are in 2013-2014 when refusals are in the data.
so the issue is most of the refusals are missing incomes as they should be but some imputation must be going on if 449 have the same income!
*/
replace earnings=monthlyjobsalary if wave>=23
replace monthlyjobearn=. if monthlyjobearn==88888888 /* 142 obs higher than 100000 pm, 12 higher than 1 million pm*/
replace earnings=monthlyjobearn if wave>=23 & earnings==.

*PSLSD 1993
replace earnings=pslsd_earnings if wave==0
tab wave, summ(earnings)
table wave, c(p1 earnings p5 earnings p50 earnings p95 earnings p99 earnings)
table wave [pw=ceweight1], c(p1 earnings p5 earnings p50 earnings p95 earnings p99 earnings)
table wave if earnings>0 [pw=ceweight1], c(p1 earnings p5 earnings p50 earnings p95 earnings p99 earnings)
table wave if earnings>0 [pw=ceweight1], c(m earnings)


*** Create a real earnings variable

*For PSLSD 1993 calculation see http://www.statssa.gov.za/publications/P0141/CPIHistory.pdf
*I'm assuming July 2000=100 below, and its 50 in the above PDF so PSLSD is 2*30,6=61.2
global CPI93Jul = 61.2
global CPI94Oct = 68.9
global CPI95Oct = 73.3
global CPI96Oct = 79.9
global CPI97Oct = 86
global CPI98Oct = 93.7
global CPI99Oct = 95.3
global CPI00Feb = 96.6
global CPI00Sep = 101.7
global CPI01Feb = 104.1
global CPI01Sep = 106.2
global CPI02Feb = 110.2
global CPI02Sep = 118.1
global CPI03Mar = 122.7
global CPI03Sep = 122.5
global CPI04Mar = 123.2
global CPI04Sep = 124.1
global CPI05Mar = 126.9
global CPI05Sep = 129.5
global CPI06Mar = 131.2
global CPI06Sep = 136.3
global CPI07Mar = 139.2
global CPI07Sep = 146.1


global CPI10Mar = 111.1*1.6			//177.76 Figure taken from P0141 December 2011, conversion of 1.6 Base year 2008 vs 2000, see P0141 Jan 2010 vs P0141 Dec 2008
global CPI10Jun = 111.5*1.6			//178.4
global CPI10Sep = 112.4*1.6			//179.84
global CPI10Dec = 113*1.6			//180.8
global CPI11Mar = 115.7*1.6			//185.12
global CPI11Jun = 117.1*1.6			//187.36
global CPI11Sep = 118.8*1.6			//190.08
global CPI11Dec = 119.9*1.6			//191.84

global CPI12Mar = 122.6*1.6			//196.16
global CPI12Jun = 123.5*1.6			//197.6
global CPI12Sep = 125.3*1.6			//200.48
global CPI12Dec = 126.7*1.6			//202.72

global CPI13Mar = 102.5*2.0272		//207.788	Figures calculated from P0141 December 2014 
									*(http://www.statssa.gov.za/publications/P0141/P0141December2014.pdf), 
									*Dec 2012 is the new base period in the reports.
global CPI13Jun = 102.91*2.0272		//208.62
global CPI13Sep = 104.8*2.0272		//212.45
global CPI13Dec = 105.4*2.0272		//213.67
global CPI14Mar = 108.7*2.0272		//220.36
global CPI14Jun = 109.7*2.0272		//222.38
global CPI14Sep = 111.0*2.0272		//225.02
global CPI14Dec = 111.0*2.0272		//225.02
*the Sep and Dec 2014 numbers are the same according to the Stats SA report!
global CPI15Mar = 113.1*2.0272		
global CPI15Jun = 114.9*2.0272		
global CPI15Sep = 116.1*2.0272		
global CPI15Dec = 116.8*2.0272
global CPI16Mar = 120.2*2.0272
global CPI16Jun = 122.1*2.0272
global CPI16Sep = 123.2*2.0272		
global CPI16Dec = 124.7*2.0272
*in 2017 the baseyear became 2016 Dec. See http://www.statssa.gov.za/publications/P0141/P0141December2017.pdf
*so I use the Dec 2016 number above as the "base" and the multiply by the CPI number (but 1.023 not 102.3)
global CPI17Mar = 124.7*2.0272*1.023
global CPI17Jun = 124.7*2.0272*1.029
global CPI17Sep = 124.7*2.0272*1.038		
global CPI17Dec = 124.7*2.0272*1.047


gen realearnings=earnings/$CPI93Jul*100 if wave==0
replace realearnings=earnings/$CPI94Oct*100 if wave==1
replace realearnings=earnings/$CPI95Oct*100 if wave==2
*replace realearnings=earnings if wave==3 /*there are no actual income amounts in OHS1996*/
replace realearnings=earnings/$CPI97Oct*100 if wave==4
replace realearnings=earnings/$CPI98Oct*100 if wave==5
replace realearnings=earnings/$CPI99Oct*100 if wave==6
replace realearnings=earnings/$CPI00Feb*100 if wave==7
replace realearnings=earnings/$CPI00Sep*100 if wave==8
replace realearnings=earnings/$CPI01Feb*100 if wave==9
replace realearnings=earnings/$CPI01Sep*100 if wave==10
replace realearnings=earnings/$CPI02Feb*100 if wave==11
replace realearnings=earnings/$CPI02Sep*100 if wave==12
replace realearnings=earnings/$CPI03Mar*100 if wave==13
replace realearnings=earnings/$CPI03Sep*100 if wave==14
replace realearnings=earnings/$CPI04Mar*100 if wave==15
replace realearnings=earnings/$CPI04Sep*100 if wave==16
replace realearnings=earnings/$CPI05Mar*100 if wave==17
replace realearnings=earnings/$CPI05Sep*100 if wave==18
replace realearnings=earnings/$CPI06Mar*100 if wave==19
replace realearnings=earnings/$CPI06Sep*100 if wave==20
replace realearnings=earnings/$CPI07Mar*100 if wave==21
replace realearnings=earnings/$CPI07Sep*100 if wave==22

replace realearnings=(earnings/$CPI10Mar)*100 if wave==31
replace realearnings=(earnings/$CPI10Jun)*100 if wave==32
replace realearnings=(earnings/$CPI10Sep)*100 if wave==33
replace realearnings=(earnings/$CPI10Dec)*100 if wave==34
replace realearnings=(earnings/$CPI11Mar)*100 if wave==35
replace realearnings=(earnings/$CPI11Jun)*100 if wave==36
replace realearnings=(earnings/$CPI11Sep)*100 if wave==37
replace realearnings=(earnings/$CPI11Dec)*100 if wave==38

replace realearnings=(earnings/$CPI12Mar)*100 if wave==39
replace realearnings=(earnings/$CPI12Jun)*100 if wave==40
replace realearnings=(earnings/$CPI12Sep)*100 if wave==41
replace realearnings=(earnings/$CPI12Dec)*100 if wave==42
replace realearnings=(earnings/$CPI13Mar)*100 if wave==43
replace realearnings=(earnings/$CPI13Jun)*100 if wave==44
replace realearnings=(earnings/$CPI13Sep)*100 if wave==45
replace realearnings=(earnings/$CPI13Dec)*100 if wave==46
replace realearnings=(earnings/$CPI14Mar)*100 if wave==47
replace realearnings=(earnings/$CPI14Jun)*100 if wave==48
replace realearnings=(earnings/$CPI14Sep)*100 if wave==49
replace realearnings=(earnings/$CPI14Dec)*100 if wave==50
replace realearnings=(earnings/$CPI15Mar)*100 if wave==51
replace realearnings=(earnings/$CPI15Jun)*100 if wave==52
replace realearnings=(earnings/$CPI15Sep)*100 if wave==53
replace realearnings=(earnings/$CPI15Dec)*100 if wave==54
replace realearnings=(earnings/$CPI16Mar)*100 if wave==55
replace realearnings=(earnings/$CPI16Jun)*100 if wave==56
replace realearnings=(earnings/$CPI16Sep)*100 if wave==57
replace realearnings=(earnings/$CPI16Dec)*100 if wave==58
replace realearnings=(earnings/$CPI17Mar)*100 if wave==59
replace realearnings=(earnings/$CPI17Jun)*100 if wave==60
replace realearnings=(earnings/$CPI17Sep)*100 if wave==61
replace realearnings=(earnings/$CPI17Dec)*100 if wave==62

*march 2019, change realearnings to dec 2017 rands for PALMS v3.3.
replace realearnings=realearnings*124.7*2.0272*1.047/100
label var realearnings "Real monthly earnings, in Dec 2017 rands."

save "`palmsmergefolder'\palmsv3.3tempa.dta", replace

