*** This is the fourth file in the creation of the PALMS income variable
*** The main purpose of this file is to create imputations for the brackets and the missings
*** The logic of this file is as follows:
***		a) We set the outliers ("outliers2") to missing and their brackets missing also. 
***		b) We impute the brackets for people with missing earnings information using an ologit
***		c) We then impute for the earnigns within the brackets by means of predictive mean matching (which in this context is basically a hotdeck)
**** M.Wittenberg June 2013

*** Modification: imputations for earnings is done by bracket. We want to also set the "don't knows" and refusals to the imputation code

*modified slightly by A Kerr, August 2013 for inclusion in the PALMS data. 
*Uses MW's PALMSwages_create4b file but is called PALMSwages_create4 to avoid confusion for the public release (4b was a modification by MW of his original 4 do file).
*revised October 2015
*revised May 2016



set more off
cap log close


local palmsmergefolder="C:\Users\01430870\Desktop\Andy\DataFirst\main project\PALMS"
cd "`palmsmergefolder'"
log using PALMSwages_create4, replace text

use palmsv3.3tempc.dta, clear
assert realearnings==0 if bracket==. & realearnings<.  &wave!=0	//PSLSD is excluded because there were no brackets. 
replace bracket=1 if bracket==. & realearnings<.	&wave!=0			// This is so that we have a monotone relationship

*** The first step is to set everything that we don't want to impute to "hard missing" 
*AK hard missing is .a and soft missing is .
*AK: hard missings are not imputed in mi but soft missings are. 

replace bracket=.a if bracket==.

replace bracket=. if employerAll!=. &wave==0					//all employed in PSLSD (we won't impute brackets for PSLSD but it helps for code below-don't have to keep making wave==0 exceptions!)
replace bracket=. if bracket==.a & empsalcat1==15				// "Don't know" in OHS 96-99
replace bracket=. if bracket==.a & empsalcat2==30				// "Unspecified" in OHS 95
replace bracket=. if bracket==.a & empsalcat3==12				// "Unspecified" in OHS 94
replace bracket=. if bracket==.a & selfempinccat1==15			// "Don't know" in OHS 99
replace bracket=. if bracket==.a & selfempinccat2==0			// "Missing" in OHS 96-98 (513 cases)
replace bracket=. if bracket==.a & selfempinccat3==30			// "Unspecified" in OHS 95
replace bracket=. if bracket==.a & selfempinccat4==14			// "Unspecified" in OHS 94

replace bracket=. if bracket==.a & jobsalcat==15				// "Don't know in LFS"
replace bracket=. if bracket==.a & jobsalcat==16				// "Refused" in LFS
replace bracket=. if bracket==.a & jobsalcat==99 & wave!=7 & wave!=8	//"Unspecified" in LFS. The 2000 surveys had way too many "unspecifieds"
replace bracket=. if bracket==.a & earningscat==20				// "Don't know" in QLFS (2010 only- no refusals in 2011 because of imputations!)
replace bracket=. if bracket==.a & earningscat==21				// "Refused" in QLFS (2010 and 2012-2014- no refusals in 2011 because of full imputations by Stats SA in Labour market dynamics!)
replace bracket=. if bracket==.a & earningscat==99				// "Unspecified" in QLFS (2011 only- not sure why?)

replace realearnings=.a if bracket==.a 
replace bracket=. if outlier2==1
replace realearnings=. if outlier2==1

***** We need to do the imputations separately for  1994/1995 and for 1996 (now also 1993 PSLSD). The only tractable way of doing that is to create 3 (now 4) separate variables

gen real93 =realearnings if wave==0
replace real93=.a if wave>0

gen real94_95 = realearnings if wave==1|wave==2
replace real94_95=.a if real94_95==. & (wave>=3 | wave==0)
replace real94_95=.a if real94_95==. & bracket==1
replace real94_95=.a if real94_95==0					// I don't want to impute zeros
gen  real96 = realearnings if wave==4					// we will impute off the 1997 figures
replace  real96=.a if  real96==. & wave!=3
replace  real96=.a if  real96==. & bracket==1
replace real96=.a if real96==0							// I don't want to impute zeros
gen  real97 = realearnings if wave>3
replace  real97=.a if  real97==. & wave<=3
*replace  real97=.a if  real97==. & wave>22
replace  real97=.a if  real97==. & bracket==1
replace real97=.a if real97==0							// I don't want to impute zeros


* we need to trim down the dataset because we will be adding a lot of variables
*drop enrolled enrollment3
drop numworkers - regisvat
drop publicemp - hhdisablegrant
drop Randinfo pr_rand

drop if wave>=23&wave<=30			// Don't have any earnings information
drop if wave>62 					//LMD 2018 not yet released so no 2018 earnings. 

count if empstat1==. & realearnings<.
keep if empstat1==1				// only people working
drop empstat1

assert realearnings>=. if bracket>=. &wave!=0
replace bracketperiod=3 if bracketperiod==.

**** now do the multiple imputation

gen int age2=age^2
assert age2~=. if age<.
compress

set seed 230613

mi set wide												
mi register imputed bracket real93 real94_95  real96  real97								
mi register regular bracketperiod wave province gender popgroup	age age2 jobindcode jobocccode	yrseduc	// These will be our explanatory variables
mi misstable summarize									// get some statistics on our data
mi misstable nested bracket real93 real94_95  real96  real97


*anyone with self-employment is missing an occup code and then there are a bunch of other wage employees also with missing occup. 
*But I need this to be consistent with imputation method done in other waves
gen pslsdjobocccode=jobocccode
replace pslsdjobocccode=10 if pslsdjobocccode==. 



mi impute monotone  (ologit bracket i.province i.gender i.yrseduc i.popgroup age age2 i.jobocccode if bracket!=1) (pmm real94_95 i.bracket#i.bracketperiod i.gender i.yrseduc i.employerAll, knn(10)) if wave<=2 &wave>0, by(wave) custom add(10) force 

mi impute pmm  real96 i.bracket#i.bracketperiod i.gender i.yrseduc i.employerAll if bracket!=1, add(10) force knn(10)
mi impute monotone  (ologit bracket i.province i.gender i.yrseduc i.popgroup age age2 i.jobocccode if bracket!=1) (pmm  real97 i.bracket i.gender i.yrseduc i.employerAll if bracket!=1, knn(10)) if wave>3, by(wave) custom add(10) force

*here is the new imputation for the PSLSD:
mi impute pmm  real93 age age2 i.gender i.popgroup i.yrseduc i.employerAll i.pslsdjobocccode if bracket!=1, add(10) force knn(10)


mi passive: generate imputed_real94= real94_95
mi passive: generate imputed_real96= real96 
mi passive: generate imputed_real97= real97
mi passive: generate imputed_real93= real93

set more off
gen int imp_bracket=bracket
foreach X of numlist 1/10{
	gen imputed_real_v`X' = _`X'_imputed_real94
	gen int imp_bracket_v`X' = _`X'_bracket
	local Y=`X'+10
	replace imputed_real_v`X' = _`Y'_imputed_real96 if wave==3			// Every call to "mi estimate" adds a set of imputations even if that variable isn't being imputed or changed...
	local Z=`X'+20
	replace imputed_real_v`X' = _`Z'_imputed_real97 if wave>3
	replace imp_bracket_v`X'=_`Z'_bracket if wave>3
	local W=`X'+30
	replace imputed_real_v`X' = _`W'_imputed_real93 if wave==0
	*no imputed brackets in 1993.
	}

save palms_temp_mi, replace

mi extract 0, clear

generate imputed_real=imputed_real94
replace imputed_real=imputed_real93 if wave==0
replace imputed_real=imputed_real96 if wave==3
replace imputed_real=imputed_real97 if wave>3
drop imputed_real94 imputed_real96 imputed_real97 imputed_real93
keep wave uqnr personnr realearnings imputed_real*

sort wave uqnr personnr
save palmsv3.3_temp_impute.dta, replace

log close
exit
