***** ADAPTING THE PSLSD TO PALMS - 2ND FILE *****

**** CREATING GENERAL VARIABLES ****

clear all
cd "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/My files"
use pslsd_empinc.dta



***INDIVIDUAL LEVEL***

**Race**

rename race popgroup

**Marriage status**

lookfor marstat //no marstat variable, have to construct it using other responses
//PALMS has marstat variable with 4 categories: married, widowed, divorced, never married;
//covering all respondents (no missing values).
//Only info is on hh roster q7: . is no spouse, low number is married, 99 is absent, 
//88 is widowed

tab spouse, m
tab age if spouse==-2 //majority of missings are under 18
tab gender if spouse==99  //more or less equal, so doesn't appear to be predominantly work-related absence
count if spouse==pcode // 34 cases list themselves as their own spouse, mark as missing
replace spouse=0 if spouse==pcode  //NOTE!

gen marstat=.
replace marstat=1 if spouse>0 & spouse!=. & spouse!=88 & spouse!=99
replace marstat=2 if spouse==88
replace marstat=3 if spouse==99
replace marstat=4 if spouse<=0 
//assumes that all those with a negative/0 value are never married, 
//Those with an absent spouse are assigned 'divorced/separated'. This seems a plausible 
//assumption given that these people have been in the hh for less than 15 days in 
//the past year. 

tab age if marstat==1  //not many under 16s are married, nobody under 12. As in PALMS they
//will be left with a married value. 


**Education**

*Years of education

//info comes from the household roster. 

tab educ, m  //variable with distinct education categories
replace educ=. if educ<0
recode educ (0=0) (1=2) (2=4) (3=5) (4=6) (5=7) (6=8) (7=9) (8=10) (9=11) (10=12) ///
  (11=11) (12=13) (13=13) (14=13) (15=13) (16=15) (17=0) (18=0) (19=.), g(yrseduc)
  //Sub A to Std 1 is given the mid-point of 2 years. 
  //other is assigned missing. those with some non-degree post-matric qualification 
  //are given 13 years total in line with PALMS. All other definitions aligned with PALMS.

*Enrollment 

//enrollment info comes from section 5: education

merge 1:1 hhid pcode using "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m4_ed1.dta"
tab hhid pcode if _merge==2 //just one not matched from using, will have to drop it
drop if _merge==2
drop _merge

tab enrol_c, m //defined for almost 30% of sample. 
tab age if enrol_c!=. //only asked for those between the ages of 6 and 23. 
tab age if enrol_c==. //very few from the relevant age range. 

gen enrollment3=3  //in PALMS variable 3 = not enrolled, variable defined for all people
replace enrollment3=1 if enrol_c==1
//Note that no info on whether enrolment is full- or part-time is available, making category 2 empty. 
//Attenuating the seriousness of this difference is the very small size of category 2 in PALMS. 

 

***HOUSEHOLD LEVEL***

**Dropping non-residents**

//While the majority of surveys in PALMS restrict the sample to those who spend on average 4 nights a week
//in the hh, the PSLSD samples any individual who has lived in the hh for 15 days of 
//the past year, shares food from a common source, and contributes to a common resource pool. 
//A further distinction is made between residents, who have spent 15 days of the past month 
//in the hh, and non-residents who haven't
//In order to look at the same sample, non-residents will be dropped (missings are left in the sample). 
//CE weights have been calculated for this sample (after dropping non-residents)

drop if resident==2

egen hhtag=tag(hhid)
tab hhtag


**Urban/rural

tab metro, m   //from strata2 file, which compiled it from the metro dta file which
//gives a metro code for each clustnum, with over 50% of clustnums being rural
tab province metro , row  
//From the codebook: 1 is rural, 2 is urban and 3 is metro!!
//All of these figures make sense. The only metro clusters come from 
//Cape, Natal, Transvaal, Kwazulu provinces. Some provinces, including Qwa Qwa Bophutatswana and Venda
//are exclusively rural. Remaining provinces contain both rural and urban 

lab define urbrurmet 1 "Rural" 2 "Urban" 3 "Metro"
lab val metro urbrurmet
lab var metro "Rural-Urban-Metro"

replace metro=2 if clustnum==206  //from metadata, was incorrectly labelled rural before

recode metro (2 3 =1) (1=2), gen(urbrur)


**Dwelling type**
//Info contained in Section 2.1: housing. 

merge m:1 hhid using "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group A/pslsd 1993 s4_hsv1.dta"

tab hhid if _merge==1 //hh's in sample (62) that don't have housing info

tab hhid if _merge==2 //hh housing info for 17 hhs that doesn't match to anything in sample

drop if _merge==2 
drop _merge

tab house_c if hhtag==1, m  //type of house variable in PSLSD, matches PALMS variable well
replace house_c =. if house_c==-1

recode house_c (1=6) (2=1) (3=2) (4=3) (5=3) (6=7) (7=5) (8=4) (9=7), gen(dwelltype)
//note category 5 from PALMS shack in backyard is 'outbuilding' in PSLSD. 

drop house_c-rent_mkt //drop unneeded variables that were merged in


**Toilet type**
//Info contained in Section 2.3 Sanitation

merge m:1 hhid using "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group A/pslsd 1993 s3_hsv2.dta"

tab hhid if _merge==2
drop if _merge==2 //17 hh's not matched from using are dropped
drop _merge

tab toilet_c, m  //type of toilet
replace toilet_c=. if toilet_c==-1  //only 30 missing values total

tab toilloc_, m  //close to 15% missing
replace toilloc_=. if toilloc_<0
//^where is the toilet? 1) inside dwelling, 2) outside dwelling-in stand, 3) outside dwelling- off stand

tab toilloc_ if toilet_c!=.   //almost 6000 missing values. Q is what to do with 
//hh's that have a toilet_c value but no location variable, assume the best? leave missing? other?
//I will look at the distribution of locations within each toilet type and if 
//a great majority (90%+) are of a certain location I will assign missings to that value. 

tab toilet_c if toilloc_==. //no observations

tab toilloc_ if toilet_c==1 //69% in dwelling, 31% on site 
tab toilloc_ if toilet_c==2 //90% on site, assume missings are onsite?
tab toilloc_ if toilet_c==3 //90% on-site
tab toilloc_ if toilet_c==4 //91% on site
tab toilloc_ if toilet_c==5 //all on-site!

gen toiletmaintype=.
replace toiletmaintype=1 if toilet_c==1 & toilloc_==1
replace toiletmaintype=2 if toilet_c==1 & toilloc_==2
replace toiletmaintype=3 if toilet_c==1 & toilloc_==3

replace toiletmaintype=4 if toilet_c==5 //NOTE: Those with a missing loc value are assumed on-site
replace toiletmaintype=5 if toilet_c==5 & toilloc_==3 


replace toiletmaintype=6 if toilet_c==2  //NOTE: Those with a missing loc value are assumed on-site
replace toiletmaintype=7 if toilet_c==2 & toilloc_==3 

replace toiletmaintype=8 if toilet_c==3  //NOTE: Those with a missing loc value are assumed on-site 
replace toiletmaintype=9 if toilet_c==3 & toilloc_==3 

replace toiletmaintype=10 if toilet_c==4  //NOTE: Those with a missing loc value are assumed on-site 
replace toiletmaintype=11 if toilet_c==4 & toilloc_==3 

replace toiletmaintype=13 if toilet_c==6

replace toiletmaintype=12 if toiletmaintype==. & toilet_c!=.  //NOTE: sets all those who 
//have a toilet type but no location to other!



**Water source**
//Info comes from Section 2.2: Water

tab wsource_, m //Main water source; only 23 missing
replace wsource_ =. if wsource_==-1

recode wsource_ (1=1) (2=2) (3=4) (4 5= 3) (6=5) (7=7) (8=8) (9=9) (10=10), gen(watersource)
//note borehole is not separated into on-site/not in PSLSD as in PALMS
//Otherwise values match perfectly. 


***ALIGNMENT OF NAMES/VALUES WITH PALMS***


gen wave=0  //where wave 1 is OHS 94

gen year=1993

gen pr_rand=1   //no bracket responses are possible so probability of answering with a rand value is 1

gen bracketweight=ceweight2  //bracketweight = ceweight2*pr_rand

rename clustnum ea  

rename pcode personnr

rename province old_province //former provinces and homelands variable
rename newprov province //current province variable

drop uqnr
gen uqnr=hhid
tostring uqnr, replace

drop metro
//note: metro must be dropped as there is a PALMS metro variable



compress

save PSLSDforPALMS.dta, replace







			

