***** ADAPTING THE PSLSD TO PALMS *****


*Note: To successfully run this do-file it is necessary to create a 'My files' 
*folder (which is set as the cd whenever the cd command is used) and to replace the location of the original PSLSD 
*data files (available on the Data First website) that follow the use and merge commands below
*to that on your hard drive



/* Note: missing values are coded as follows:
-1 : The data was not available on the questionnaire or form
-2 : The field is not applicable
-3 : Respondent refused to answer
-4 : Respondent did not know answer to question
*/

/* Note: other response codes:
88 : person concerned is deceased
99 : person concerned is absent
*/




**** CREATING INCOME VARIABLES ****

*Here an income variable will be calculated using only income that comes directly from
*labour, namely from regular employment, casual employment or self-employment.
*Final variable realearnings will contain income only from one main source.


***REGULAR WAGE INCOME***

*From CLCINC21.DO
*Individual level data asked to all hh members 16+. From section 8.2 of questionnaire
 

clear all
cd "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/My files"
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m6_remp.dta"

set more off

sort hhid
by hhid: gen dup= cond(_N==1,0,_n) 
tab dup 

di 3515+1806
//5321 hhs have at least one person earning a regular wage. 7513 people earn a regular wage.



**Gross-Net Conversion**


*A respondent is asked for both gross and net wages.

gen gross_miss =0
replace gross_miss=1 if p_grossp<0 | p_grossp==.
tab gross_miss

gen net_miss =0
replace net_miss=1 if p_netpay<0 | p_netpay==.
tab net_miss

tab net_miss if gross_miss==1 //352 of the people with missing gross values have
//a net value recorded. the other 804 make up almost all the missing net values

replace p_grossp=. if gross_miss==1 //sets all missing codes to .
replace p_netpay=. if net_miss==1 //sets all missing codes to .

drop gross_miss net_miss


*Convert incomes into monthly figures

tab p_paytyp, m  //A respondent could give income in weekly, fortnightly or monthly amounts. 

gen mnetpay=.
lab var mnetpay "Monthly net pay"
replace mnetpay=p_netpay      if p_paytyp==3 & p_netpay>=0
replace mnetpay=p_netpay*2.15 if p_paytyp==2 & p_netpay>=0
replace mnetpay=p_netpay*4.3  if p_paytyp==1 & p_netpay>=0 

gen mgrspay=.
lab var mgrspay "Monthly gross pay"
replace mgrspay=p_grossp      if p_paytyp==3 & p_grossp>=0
replace mgrspay=p_grossp*2.15 if p_paytyp==2 & p_grossp>=0
replace mgrspay=p_grossp*4.3  if p_paytyp==1 & p_grossp>=0

save reginc1, replace



*Process to calculate median tax rates per quartile to calculate missing gross incomes
*from net incomes and vice versa

drop if (mnetpay==0 | mnetpay==.) & (mgrspay==0 | mgrspay==.)
keep hhid pcode mnetpay mgrspay 
gen mnetp2=mnetpay if mnetpay!=0
replace mnetp2=mgrspay*.9 if mnetpay==0  //0.9 is an estimate of the tax rate for the purposes of ranking
sort mnetp2
gen rank=group(4)    //creates a variable giving a 1/4 of the cumulative dist of mnetp2
tab rank //people in the same quarter of the distribution are then assumed to have the
//same gross to net relationship

sort rank
save step1,replace

drop if mnetpay==0 | mgrspay==0 

sort rank

gen taxratio=mnetpay/mgrspay
egen ratmed=median(taxratio), by (rank) //for the bottom quarter the median is 1, implying no tax
//drops to 0.7 by 4th quarter
tab ratmed
sort rank
keep ratmed rank

by rank: gen dup= cond(_N==1,0,_n)
drop if dup>1

save step2,replace

clear all
use step1
merge m:1 rank using step2
sort hhid pcode
tab _merge
drop _merge
save step3,replace

use reginc1
sort hhid pcode
merge 1:1 hhid pcode using step3
tab _merge
drop _merge

gen npay=mnetpay
gen gpay=mgrspay
replace mnetpay=mgrspay*ratmed if (mnetpay==0 | mnetpay==.) & mgrspay>0 //IMP//
replace mgrspay=mnetpay/ratmed if (mgrspay==0 | mgrspay==.) & mnetpay>0 //IMP//
sum mnetpay if mnetpay>0  //1249
sum mgrspay if mgrspay>0  //1819 (3596), has decreased slightly from 1841 before imputation

//Missing values have been estimated from net income where a net value is recorded. 
//759 observations remain missing. 



**Summation of various sources of income** 


gen monthben=0
lab var monthben "Monthly Benefits"
replace monthben=p_bonus/12 if p_bonus>0 & p_bonus~=.  //creates a monthly benefit variable

gen monthprf=0
lab var monthprf "Monthly Profit Share"
replace monthprf=p_profit/12 if p_profit>0 & p_profit~=. //creates a monthly profit share variable


tab subs_t, m

gen monthtvl=0
lab var monthtvl "Monthly Transport Subsidy"
replace monthtvl=0
replace monthtvl=subs_t      if p_paytyp==3 & subs_t>0 & subs_t~=.
replace monthtvl=subs_t*2.15 if p_paytyp==2 & subs_t>0 & subs_t~=.
replace monthtvl=subs_t*4.3  if p_paytyp==1 & subs_t>0 & subs_t~=.

gen montheat=0
lab var montheat "Monthly Food Subsidy"
replace montheat=0
replace montheat=subs_f      if p_paytyp==3 & subs_f>0 & subs_f~=.
replace montheat=subs_f*2.15 if p_paytyp==2 & subs_f>0 & subs_f~=.
replace montheat=subs_f*4.3  if p_paytyp==1 & subs_f>0 & subs_f~=.

gen mnhouse=0
lab var mnhouse "Monthly Housing Subsidy"
replace mnhouse=0
replace mnhouse=subs_h       if p_paytyp==3 & subs_h>0 & subs_h~=.
replace mnhouse=subs_h*2.15  if p_paytyp==2 & subs_h>0 & subs_h~=.
replace mnhouse=subs_h*4.3   if p_paytyp==1 & subs_h>0 & subs_h~=.

//^in all cases missing or negative responses are assigned to = 0

gen subsidies=monthtvl+montheat+mnhouse

gen nwageinc=mnetpay+monthben+monthprf 
lab var nwageinc "Net Wage Income"

gen gwageinc=mgrspay+monthben+monthprf 
lab var gwageinc "Gross Wage Income"

gen nwageinc_subs=mnetpay+monthben+monthprf+subsidies
lab var nwageinc_subs "Net Wage Income with Subsidies"

gen gwageinc_subs=mgrspay+monthben+monthprf+subsidies
lab var gwageinc_subs "Gross Wage Income with Subsidies"


tab mgrspay if monthben!=. | monthprf!=.  | subsidies!=., m  //853 (11.35%) missing

//if gross wages was missing (even after imputation from net) then total inc is also
//missing as it does not make sense to calculate it without knowing the base wage. 
//If gross is missing and bonus is 0 final value will be missing. 


*Generating a full-time indicator

tab k_hours, m 
//average hours worked per day variable. 60 values <=0 or missing. Some above 24!
replace k_hours=. if k_hours>=20 | k_hours<0 //sets implausible hours to missing 
//reasonable cutoff? very few values higher than this
gen regfulltime = 0
replace regfulltime=. if k_hours==. | k_hours<0
replace regfulltime=1 if k_hours>=5 //if this is 1 then use this income as their overall income value
//means that anyone working less than 25 hours a week is assumed not to work fulltime.
//0 hours worked is assigned missing 

gen regearner=1

save indreginc, replace
 


***CASUAL WAGE INCOME***

*Asked to all members of a household, including children. Individual level data
*From section 8.3 in the questionnaire. 

clear all
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m3_casw1.dta"

//937 observations from 840 hhs

sort hhid
by hhid: gen dup= cond(_N==1,0,_n)
tab dup

tab pcode, m

tab cash_pai

*Replace m

replace cash_pai=. if cash_pai<0  //sets all missing codes to .
replace food_ben=. if food_ben<0  //sets all missing codes to .
replace benefit_=. if benefit_<0  //sets all missing codes to .

sum cash_pai //441.61 mean (845.76)

tab cash_pai, m //one big outlier at 16000
tab food_ben, m //no outliers
tab benefit, m //one exteme outlier at 2905



//Andrew summed cash_pai with food_ben and benefit_ to calculate total earnings
//whereas the original file kept them separate and then sums them at the end. 
//I am interested in in-kind payment and so will sum them. 

gen c1totwage= cash_pai+food_ben+benefit_
replace c1totwage=. if cash_pai==. //not meaningful unless base earnings are known? 
//What about people who are only paid in-kind?? Then they should have 0
tab cash_pai if food_ben!=. | benefit_!=., m //this only affects 31 obs

gen casearner=1

save indcasw1, replace


use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m1_casw2.dta", clear
//30 individuals have a second casual job and income. 


***SELF-EMPLOYMENT INCOME***

*Questionnaire Section 8.6 , to be completed for all persons of any age,  
*However, info is not at ind level but at hh level
*Each observation is one activity of an hh, with a variable asking for top 1-3 most involved hh members
*Asks for any work apart from other work already mentioned in regular and casual sections


clear all
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m3_semp.dta"
set more off

sort hhid
by hhid: gen dup= cond(_N==1,0,_n)
tab dup

di 1035+48
//1083 hhs engage in some form of self-employment, with 1135 total activities (meaning some 
//hhs engage in multiple activites)


*Assessing variables and missing values

tab activ1_c, m //activity code, just 2 -3s 
tab  hhid if activ1_c==-3
drop if hhid==148001 | hhid==170018 //observations are dropped as almost all data 
//missing or negative including activity
rename activ1_c business

tab profit_1, m //average monthly profit
di 85+49+2 //only 136 missing values of 1135 obs

tab grtime_1, m //gross time - 58 negative values

tab grsales_, m //gross sales: 123 missing
tab expen_1, m //total expenses: 134 missing

gen calcprof=.
replace calcprof= grsales_ - expen_1 if grsales_>=0 & expen_1>=0
replace profit_1=calcprof if profit_1<=0 & calcprof>0 & calcprof~=. //IMP , those with
//a missing or 0 profit value are given sales - expenses. 
replace profit_1=. if profit_1<0
//although for observations with a profit value recorded this often doesnt follow
//gross sales - expenses, this seems like a reasonable way to calculate missing values. 

replace grsales_=. if grsales_<0
replace expen_1=. if expen_1<0
replace grtime_1=. if grtime_1<0



**Calculating individual-level variables for hours worked and profit**

//Using code from Andrew Kerr, Data First
//Andrew assumed equal contribution for profit and time spent by hh, dividing these 
//by number of people listed. Problematic for two reasons:1) ignores differential levels
//of effort(time) put in as reflected in their ranking, 2) ignores the real 
//possibility of more than 3 members being involved

tab mcode1_c, m
tab mcode2_c, m
tab mcode3_c, m
recode mcode1_c mcode2_c mcode3_c (-2=.) (-1=.)


egen people=rownonmiss(mcode1_c mcode2_c mcode3_c) //creates a variable giving 
//number of people involved in each activity

tab people, m 
//Thus the above two problems cannot be too serious. 2) Only 81 activities list 3
//involved members, and 76.65% only involved one member 


*Division of hh activity totals by individuals

gen indprofit=profit_1/people //IMP//

recode grtime_1 (-1=.) (-2=.) (-3=.) (-4=.)
g self_hrs_wor=grtime_1/people //IMP//


tostring hhid mcode1_c mcode2_c mcode3_c, generate(hhidstr pcodestr1 pcodestr2 pcodestr3)
gen unqpcode1=hhidstr+"0"+pcodestr1
gen unqpcode2=hhidstr+"0"+pcodestr2
gen unqpcode3=hhidstr+"0"+pcodestr3


keep hhid unqpcode1 unqpcode2 unqpcode3 people indprofit business self_hrs_wor
save myselfemp1,replace


*Single person businesses

keep if people==1   //drops all businesses with more than 1 member
drop unqpcode2 unqpcode3  
rename unqpcode1 unqpcode
sort unqpcode
by unqpcode: egen numbus=count(business)
tab numbus // 10 individuals have 2 businesses
keep unqpcode business indprofit self_hrs_wor
collapse (sum) self_hrs_wor (sum) indprofit (max) business, by(unqpcode)  //now there is one observation per individual worker
//Two arbitrary decisions had to be taken here (and further below):
//1) to use sum profit and hours worked rather than the mean! 
//2) to use the max (higher) business value 
rename indprofit indprofit1

save myselfemp2,replace

*2 people businesses

use myselfemp1,clear
keep if people==2
drop unqpcode3
save myselfemp3,replace
//Multiple business households involving multiple people - assign row ID to enable reshape
generate id=_n
reshape long unqpcode, i(id) j(pcode) 
collapse (sum) self_hrs_wor (sum) indprofit (max) business, by(unqpcode)  //now there is one observation per individual worker
rename indprofit indprofit2

save myselfemp3,replace

*3 people businesses

use myselfemp1
keep if people==3
sort hhid
//Need a manual addition for hh with 3 members involved in 2 businesses 
replace indprofit = 40 in 75 //40 is the sum of indprofit in both businesses
replace self_hrs_wor = 101 in 75 //101 sum of ind hours in both businesses
drop if hhid ==287003 &business==3 //one of the businesses can then be dropped

sort hhid
by hhid: gen dup= cond(_N==1,0,_n)
tab dup //no more duplicates present
drop dup

reshape long unqpcode, i(hhid) j(pcode)
keep unqpcode business indprofit self_hrs_wor
rename indprofit indprofit3

sort unqpcode
by unqpcode: gen dup= cond(_N==1,0,_n)
tab dup
*br unqpcode indprofit business self_hrs_wor if dup>0 //identical on all characteristics
drop if dup>1  //therefore, appear to be mistaken duplicate and one is dropped
drop dup

save myselfemp4,replace



**Merging of various business size incomes**

use myselfemp2
merge 1:1 unqpcode using myselfemp3
tab unqpcode if _merge==3 //4 people are involved in 1 and 2 person businesses
drop _merge

merge 1:1 unqpcode using myselfemp4
//3 people who have smaller self-employment activities
drop _merge

egen indprofit = rowtotal(indprofit1 indprofit2 indprofit3) 
//Profits from various sizes of business are summed
drop indprofit1 indprofit2 indprofit3

rename indprofit selfemp_inc

tab selfemp_inc, m  //some outliers at 80000 and 100000 but no extreme jumps
tab self_hrs_wor, m  
//^Monthly values for hours worked, change to daily to make them comparable with other
//hours worked variables
replace self_hrs_wor= self_hrs_wor/(5*4.3) //assuming 5 working days per week and 4.3 weeks 
//per month

replace self_hrs_wor=. if self_hrs_wor>20  //as was done for the other hours variable


lab var self_hrs_wor "Average hours worked per day"
lab var selfemp_inc "Monthly income from self-employment"

gen selfearner=1



save indselfw, replace


***COMBINING INCOME SOURCES***


**Creating a dataset with essential household and individual information**


clear all 
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group A/pslsd 1993 m8_hrost.dta", clear
*From Section 1 of the questionnaire: hh roster
*8809 hhs, with 43687 individuals
*Any individual who has lived in the hh for 15 days of the past year, shares food from a common source, 
*and contributes to a common resource pool is included in questionnaire

sort hhid pcode
by hhid pcode: gen dup= cond(_N==1,0,_n)
tab dup
drop dup

tab resident,m  //only about 8% are non-resident.  
replace resident=. if resident<0

tab abs_mont, m  //how many months spent away from hh in previous 12. Could be used to create a 
//differently defined resident variable.
tab abs_mont if resident==.   //most are not absent for any months so leave in sample
tab age if resident==.
tab abs_mont if resident==2 //varies but most are more than 2

tab absence_, m //reason for absence
tab absence_ if resident==1 //most are away for visiting family
tab absence_ if resident==0 //most are away for employment, confirming that they are migrant labourers




sort hhid pcode
by hhid pcode: gen dup= cond(_N==1,0,_n)
tab dup //no duplicates
drop dup

tostring hhid pcode, generate(hhidstr pcodestr)
gen unqpcode=hhidstr+"0"+pcodestr

save myroster, replace


clear all
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group C/pslsd 1993 strata2.dta", clear
*Contains all weights info and general info (race, lang, metro etc.) for 8809 unique hhs
*Original weights are either enumeration-raised (rsweight) or census-raised (csweight)

sort hhid
by hhid: gen dup= cond(_N==1,0,_n)
tab dup //no duplicates
drop dup

*Merging in of new weights cross-entropy weights calculated at the household level 
*and without migrants

gen uqnr=hhid
merge m:1 uqnr using "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/My files/pslsd_1993_new_wgt_20160307.dta"
//17 hh's from master not matched!! figure out why (they matched fine in emp residents)
drop _merge

drop ceweight2 ceweight2y
rename ceweight2x ceweight2  
//ceweight2 is a cross-entropy weight calibrated to the ASSA model of the South 
//African population and considering the rsweights as a prior distribution


merge 1:m hhid using myroster //all 40,144 matched
drop _merge



**Merging income data into this file**

merge 1:1 hhid pcode using indreginc //6 not matched from using
tab unqpcode if _merge==2
drop if _merge==2
drop _merge

rename k_hours reg_hours
rename k_occ_c reg_occ
rename k_sector reg_sector


merge 1:1 hhid pcode using indcasw1  //just 1 of 937 not matched
drop if _merge==2
drop _merge

rename hours_v cas_hours
rename sector_c cas_sector
rename occupatn cas_occ
rename c1totwage cas_inc


merge 1:1 unqpcode using indselfw  //4 not matched from using
drop if _merge==2
drop _merge

rename self_hrs_wor self_hours
rename business self_activity


replace reg_hours=reg_hours*5
replace cas_hours=cas_hours*5
replace self_hours=self_hours*5
//^hours worked variables are now converted into weekly variables, assuming 5 days worked

replace cas_hours=. if cas_hours<0
replace self_hours=. if self_hours<0


*Convert incomes to 2000 values

//PSLSD conducted nine months prior to April 94 elections, making it July 1993 which
// has a CPI of 30.82
// June 2000 CPI is 49.82

gen nom_gwageinc_subs=gwageinc_subs
gen nom_cas_inc=cas_inc
gen nom_selfemp_inc=selfemp_inc

replace gwageinc_subs = (gwageinc_subs*49.82)/30.82
replace nwageinc_subs = (nwageinc_subs*49.82)/30.82
replace cas_inc = (cas_inc*49.82)/30.82
replace selfemp_inc = (selfemp_inc*49.82)/30.82


egen top_inc = rowmax(gwageinc_subs cas_inc selfemp_inc)
egen top_hours = rowmax(reg_hours cas_hours self_hours)


**Generating final earnings variables

*realearnings 

//Regular (gross) income will be used as the base value and replaced by the top 
//income (of the three sources) only if regular income is missing and/or the worker 
//is not a full time regular worker. 

gen realearnings = gwageinc_subs   

count if regfulltime==0 //so less than 93 workers will be affected by this change

replace realearnings=top_inc if  regfulltime==0 | regearner!=1 
//This is calculated for gross inc and not net inc because both the casual and
//self-emp sections are phrased far more in gross terms, and because after 1994 
//PALMS exclusively uses gross earnings. 

*earnings (nominal)

egen nom_top_inc = rowmax(nom_gwageinc_subs nom_cas_inc nom_selfemp_inc)
gen earnings=nom_gwageinc_subs
replace earnings=nom_top_inc if  regfulltime==0 | regearner!=1 


*Creating a variable that tells you which is the source of income in realearnings (or earnings)

gen tempreg = gwageinc_subs
replace tempreg= . if (regearner!=1 | regfulltime!=1) & tempreg<top_inc

gen tempcas = cas_inc
replace tempcas=. if selfemp_inc>cas_inc

gen emptype=.
replace emptype = cond(missing(tempreg), cond(missing(top_inc),.,cond(missing(cas_inc), 3, 2)) , 1)
//generates a variable that tells you what the source of the income amount listed in final_wage is!

drop tempreg tempcas


save totlabourinc.dta, replace


*Calculating how many people have multiple sources of income

gen multiple_inc=.
replace multiple_inc=0 if (gwageinc_subs>0 | cas_inc>0 | selfemp_inc>0) & (gwageinc_subs!=. ///
| cas_inc!=. | selfemp_inc!=.) //all earners set to 0
replace multiple_inc =1 if (gwageinc_subs>0 & cas_inc>0 & selfemp_inc>0 & gwageinc_subs!=. & cas_inc!=. & selfemp_inc!=.) | (cas_inc>0 & ///
selfemp_inc>0 & cas_inc!=. & selfemp_inc!=.) | (gwageinc_subs>0 & cas_inc>0  & gwageinc_subs!=. & cas_inc!=.) | (gwageinc_subs>0 & selfemp_inc>0 & gwageinc_subs!=. & selfemp_inc!=.) 
//multiple earners set to 1
tab multiple_inc   //only 165 multiple earners of 8,791 (1.88%) 




***CALCULATING INCOME FROM GRANTS***

clear all
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m5_ines.dta", clear
*From Section 8.7, data is already stored at the individual level, sorted by hhid and pcode
*all at ind level (so match to the OHS variable)
*PALMS variable is merely yes/no (does the person receive?), so the amount received here is not relevant. 

				

set more off

egen hhtag=tag(hhid)

sort hhid pcode source_c
by hhid pcode source_c: gen dup= cond(_N==1,0,_n)
tab dup  //no duplicates of one person receiving the same type of income
drop dup

by hhid pcode: gen dup= cond(_N==1,0,_n)
tab dup //8 people receiving 3 sources and 149 receiving 2. 
drop dup

sort hhid source_c
by hhid source_c: gen dup= cond(_N==1,0,_n)
tab dup if hhtag==1 //382 hh's with multiple recipients of the same kind
tab source_c if dup>0  //79% are pension recipients. 
drop dup

tab source_q, m  //3342 respondents (of 3344) in this data file said yes to receive income
tab source_c //values from 1 to 15 whereas Q only goes up to 12! 

gen incpension=.  //NOTE: unspecified is marked 9 in PALMS but here we only have info
//for those who responded yes so I will leave all other observations with a missing value. 
//Therefore for the PSLSD it will serve more as a missing/1 marker for receipt
replace incpension=1 if source_c==1 //

gen incdisabgrnt=.
replace incdisabgrnt=1 if source_c==4

*gen inctstmaint=.  //state maintenance/ child support grant
*replace inctstmaint=1 if source_c==5     //govt poor relief is the only category that might fit

*gen incdepgrnt=.
*replace incdepgrnt=1 if source_c==

*gen incfostcrgrnt=.
*replace incfostcrgrnt=1 if source_c==

//The last three don't have equivalents in PSLSD. However, PSLSD has several other 
//categories which could contain info in new variables if need be. 

sort hhid pcode
collapse (sum) incpension incdisabgrnt ,by(hhid pcode)

replace incpension=. if incpension==0
replace incdisabgrnt=. if incdisabgrnt==0

save nonlabinc.dta, replace

use totlabourinc.dta, clear

merge 1:1 hhid pcode using "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/My files/nonlabinc.dta"
drop if _merge==2
drop _merge

save totinc.dta, replace




**** CREATING EMPLOYMENT VARIABLES ****

***CREATING EMPSTATS***

**Preparing data with employment status variables

clear all
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m8_emps.dta"
*Data from Section 8.1 'Employment Status
*contains employment status information for all people 16 or older

*Number households

sort hhid
by hhid: gen dup= cond(_N==1,0,_n)
tab dup

di 1860+6938 //8798 unique hhs (8809), with 24296 respondents (vs 43687 total on roster)
drop dup

*Duplicate observations

sort hhid pcode
by hhid pcode: gen dup = cond(_N==1,0,_n)
tab dup

replace pcode=1 in 2206  //this hh has two working age individuals (1&2) so change what  appears to be a typo
replace pcode=2 in 18761

drop dup

**Employed/unemployed conditions**


tab unempl_q, m  //only 4 missing values, 1 is employed, 2 is not. 
//9406 said yes to employment. (8515 have income data for final_inc)
replace unempl_q=. if unempl_q<0
drop if unempl_q==. 

*Hours worked in past week
tab hours_wo, m //hours worked in last week variable
tab hours_wo if unempl_q==1, m //101 missing, 188 0s
tab hours_wo if unempl_q==2 //almost all 0. 
//very few of the employed worked below 5 hours in the previous week but this will be 
//assigned not employed in line with OHSs
replace hours_wo=. if hours_wo<0


*Would have liked more work (CONDITION 1)
tab more_wor, m //157 missing   4118 yes
tab more_wor if unempl_q==1 //1394 of those  employed wanted more work 
tab more_wor if unempl_q==2 //2723 of those not employed wanted more work 
replace more_wor=. if more_wor==-1


*Looked for job in past week (CONDITION 2 NARROW)
tab look_wor,m
tab look_wor if unempl_q==2 //1387 of those not employed looked for work in the past 
//week and thus satisfy the narrow unemployed definition
tab look_wor if unempl_q==1 //4% of the employed looked for more work
replace look_wor=. if look_wor<=0 | look_wor==42
tab look_wor if more_wor==1 & unempl_q==2, m  //1164, under half of unemployed work seekers
//are actively seeking work
tab more_wor if look_wor==1, m //strangely 240 of those who looked for work didnt want it. 


*Separating those who didn't look into discouraged seekers (CONDITION 2 BROAD) and 
//those out of the lf 

tab reason_n, m //no missing, around 8% negative
tab reason_n if look_wor==1 //all -2 as they should be, good
tab reason_n if look_wor==2 //only 74 missing (negative) values. 

//Beyond this there is info for those who looked for work in past week about 
// reservation wages, method of job search and past work. 

drop time_spe-sector

save empstat.dta, replace


**Generating empstats**

clear all
use totinc.dta

sort hhid pcode
merge 1:1 hhid pcode using empstat
//10 not matched from using

tab  pcode if _merge==2 
drop if _merge==2 //These observations cannot be matched, have no demographic info and must be dropped. 
drop _merge

*Clean demogrpahic variables needed for empstats

gen gender=.
replace gender=1 if gender_c=="M"
replace gender=2 if gender_c=="F"
lab define sex 1 "Male" 2 "Female"
lab val gender sex

tab age, m
replace age=. if age<0
replace age= age-1  //in the PSLSD respondents were asked for their age at their NEXT birthday
//So 1 must be substracted to get current age. 


*Narrow empstat

gen empstat1=.
replace empstat1=0 if age>=15   //as in PALMS OHSs only those under 15 are assigned missing

tab unempl_q if absence_==1 | absence_==13, m //60 listed as unemployed, give this precedence. 

tab hours_wo if empstat1==1 
replace unempl_q =2 if unempl_q==1 & hours_wo<5 //Less than 5 hours work in a week is considered not employed

replace empstat1=1 if unempl_q==1 
tab empstat1 if absence_==1 | absence_==13, m //all those listed as away for employment 
//and business trips are over 15 but only 240 (10%) listed as employed (87% missing). 
replace empstat1=1 if (absence_==1 | absence_==13) & unempl_q!=2 
tab empstat1 if reason_n==1, m  //only 19 of those who said they did not look for work
//because they were employed are listed as not employed
replace empstat1 =1 if reason_n==1
tab empstat1 if regearner==1 | casearner==1 | selfearner==1, m //289 earners not listed as employed 
replace empstat1 = 1 if  regearner==1 | casearner==1 | selfearner==1 


replace empstat1=2 if unempl_q==2  & look_wor==1 //those unemployed are those who have
//looked for work in the previous week

replace empstat1 =. if age<15  //ensure that all underage are still missing after all adjustments are made



*Broad empstat

gen empstat2=.
replace empstat2=0 if age>=15   
replace empstat2=1 if unempl_q==1 & hours_wo>=5
replace empstat2=1 if absence_==1 | absence_==13
replace empstat2=1 if reason_n==1
replace empstat2=1 if  regearner==1 | casearner==1 | selfearner==1 

replace empstat2=2 if (unempl_q==2 & look_wor==1) | (unempl_q==2 & look_wor==2 & reason_n==2)
//a broader range of people are assigned to be unemployed (See conditions above)

replace empstat2 =. if age<15

save dataemp, replace



***OTHER EMPLOYMENT VARIABLES***

use dataemp, clear

**Industry**

//Employment status section gives info on sector of last job but not current
//Regular emp contains a sector variable, as does casual while self only has a business section
//Self employment 'business' categories do not really match up and will be left as missing. 

tab reg_sector, m
replace reg_sector=. if reg_sector<0

tab cas_sector, m
replace cas_sector=. if cas_sector<0

//Both use the same values. 

gen empsector=.
replace empsector=reg_sector if emptype==1
replace empsector=cas_sector if emptype==2

tab empsector
tab empsector, m
recode empsector (5=5) (6 7= 6) (8 = 7) (9=8) (10 11 12 14 15 = 9) (13=10) (16=.), gen(jobindcode) 
//7 restaurants and hotels goes under services or trade??
lab define industries 1 "Agriculture, hunting, forestry and fishing" 2 "Mining and quarrying" 3 "Manufacturing" 4 "Utilities" 5 "Construction" 6 "Trade" 7 "Transport" ///
8 "Finance" 9 "Services" 10 "Domestic Services" 
lab val jobindcode industries


**Occupation**

//Both regular and casual have the same occupation codes

tab reg_occ, m 
replace reg_occ=. if reg_occ<0

tab cas_occ, m
replace cas_occ=. if cas_occ<0

*Assign an occ code coming from their main source of income

gen empocc=.
replace empocc=reg_occ if emptype==1
replace empocc=cas_occ if emptype==2  

recode empocc (1=2) (2=1) (3=4) (4 5=5) (6=6) (7=7) (8 9=8) (10=9) (11=.), gen(jobocccode) //just 3 and 10 are left empty..

//Note that professionals and technical occupation are one category in PSLSD and cannot be separated. 
//Difficult to place 2 (managerial and administrative occupations, placed in 1) and 4 (transport etc, 5)


**Employer type**

*employer1
//who does ind work for? N/A; someone else; him/herself; both
//Will use earner tags to calculate. 

gen employer1=.
replace employer1 = 0 if age>9 
replace employer1 = 1 if regearner==1 | casearner==1
replace employer1 = 2 if selfearner==1 & regearner!=1 & casearner!=1
replace employer1 = 3 if selfearner==1 & (regearner==1 | casearner==1)

tab job_desc //job description variable that also contains relevant information
replace job_desc=. if job_desc<0

replace employer1=2 if (job_desc==3 | job_desc==4) & employer1==0 //74 changes
//those who reported being self-employed and do not have a value from the earnings sections


*employerAll

//States whether an individual's income comes from wage labour or self-employed labour
//0=wage employment 1=self employment
//Will simplify the emptype variable which has an extra 'casual' category


gen employerAll=.
replace employerAll=0 if emptype==1 | emptype==2
replace employerAll=1 if emptype==3


**Hour worked last week variable**

tab hours_wo, m  //from employment status page, follows 'is x employed' and 'type of work' variable
tab hours_wo if empstat1==1,m  //only 358 0s and 2044 missing of 11457 observations. 

//how does this line up to other hours worked variables from specific employment types 
//(casual and regular are originally daily but now multiplied by 5 for weekly)
tab top_hours if empstat1==1 & (hours_wo==. | hours_wo==0), m  //less than 400 obs have 
//an specific hours and a missing general hours. 

tab hours_wo, sum(top_hours) //top_hours is a lot more narrowly distributed

rename hours_wo hrslstwk


**Job start date**
// jobstartyear and jobstartmonth only present in LFSs and QLFSs in PALMS
// A: Nothing in PSLSD


***WAGE LABOUR VARIABLES***


**Formal/Informal**
// wageformalreg (OHS variable) in PALMS 0=missing/dont know 1=formal 2=informal (incl domestic)
//A: Nothing in PSLSD, except for the regular/casual distinction, which could be used
//in conjunction with ind codes to recreate variable...


**Public Sector**
//1 if ind is employed in public sector, 0 otherwise
//in PSLSD information can be taken from q 3b of regular employment: Who does ___ work for?

tab k_emplyr if empstat1==1 & regearner==1, m  //almost all positive responses come from this subset. 

recode k_emplyr (1 2 3 4=1) (5/9=0) (-4/-1=.), gen(publicemp)  //central government, provincial admin and
//local/regional authorities are considered public sector employees
//unclear whether public corporation is publicly traded company or govt owned company but
//seems likely its the former given that 5 is private sector employer. 


**Business type (that ind works for)**
//variable in LFSs and QLFSs. The categories from businesstype1 (earlier LFSs) match
// k_emplyr perfectly

recode k_emplyr (6=5) (5=6) (7=6) (8 9=9) (-4=7) (-3 -1=.), gen(businesstype1)

*BUT the same info should be used from casual workers as well!

tab emptype, m
tab businesstype1 if employer!=. //employer is the casual equivalent of k_emplyr
tab employer // same values as k_emplyr
recode employer (6=5) (5=6) (7=6) (8 9=9) (-4=7) (-3 -1=.), gen(castype1)
replace businesstype1 = castype1 if emptype==2 


**Written contract**
//1 if ind has written contract with employer
//A: Nothing in PSLSD!

**Number co-workers**
// numworkers - number of workers at individuals place of work. (valid range 1 to 9,defined for LFS, see numworkers2 for QLFS for wider range) 
//A: Nothing in PSLSD

**Union membership**
//Info comes from Q 5f of the regular employment section. No info for casual etc.  
//in PALMS jobunion = 1 union member 2 not a union member 3 don't know 9 unspecified, set those not employed to missing

tab subs_tu, m  //1=yes (member) 2=no 
tab subs_tu if empstat1==1 & regearner==1,m  //Just over 2% missing!

recode subs_tu (-4/-1=3), gen(jobunion)

save pslsd_emp.dta, replace


***SELF EMPLOYMENT VARIABLES***


**Formal/Informal

*selfformalreg : self-employed ind considers their business to be formal  (not for OHS the self and wage formal classifications are separate variables, in LFS just one)
//A: Nothing in PSLSD

*selfvatreg: self-employed business is VAT registered. 
//A: Nothing in PSLSD


**Number of Employees**

*In PALMS: selfpaidemp: number of paid employees in the self-employed individuals business. 
*selfunpaidemp: number of unpaid employees. 

//In PSLSD up to 3 household members can be listed and a separate question 
//measures how many non-members are involved in the activity. No info about whether they are 
//paid but one can assume externals are? But still PSLSD is hh level while PALMS is ind level

//Unlike in the income calculations, here it makes sense to have the employees variable at the hh level
//or only for the first listed member. The variables below use assign employees only to the first listed member.


*Creating self number employees variable

clear all
use "/Users/Gabriel/Documents/DataFirst Work/PSLSD Project/Data/Stata/Group B/pslsd 1993 m3_semp.dta"
set more off

drop mcode2_c mcode3_c //the variable will have a value only for the 1st pcode listed

sort hhid mcode1_c
by hhid mcode1_c: gen dup= cond(_N==1,0,_n)
tab dup
//8 people are twice listed first in an activity. 

rename mcode1_c pcode

tab other_em, m //q9 ; how many people excluding hh members are employed
replace other_em=. if other_em<0

collapse (sum) other_em , by(hhid pcode)  //following the precedent of income, the 
//employees of the individual's  multiple businesses are summed

rename other_em selfpaidemp

save selfemploy.dta, replace


*Merging this variable into the data set

clear all
use pslsd_emp.dta

merge 1:1 hhid pcode using selfemploy.dta
tab hhid pcode if _merge==2
drop if _merge==2 //just 1 not matched from using
drop _merge

				
**Business type**
//In PSLSD each self-employment hh-level activity has a business code. But the
//variable in LFSs and QLFSs is hh-level and is definitely for wage labourers. 
//So appears that PSLSD 'business' can't be matched to anything

	
save pslsd_empinc.dta, replace

	







				








